==> jc-1.4.0.tar.gz: java/beans/ExplicitInfo.h <==
// class java.beans.ExplicitInfo

// class file dependencies
// @dep_class da01681b6d99988b java_beans_ExplicitInfo
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_beans_ExplicitInfo_H_
#define _JC_java_beans_ExplicitInfo_H_

// Forward structure declarations
struct _jc_java_beans_BeanDescriptor$object;
struct _jc_java_beans_BeanInfo$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;
struct _jc_java_util_Vector$object;

// Typedefs
typedef struct _jc_java_beans_ExplicitInfo$sub_refs	_jc_java_beans_ExplicitInfo$sub_refs;
typedef struct _jc_java_beans_ExplicitInfo$sub_nonrefs	_jc_java_beans_ExplicitInfo$sub_nonrefs;
typedef struct _jc_java_beans_ExplicitInfo$refs	_jc_java_beans_ExplicitInfo$refs;
typedef struct _jc_java_beans_ExplicitInfo$nonrefs	_jc_java_beans_ExplicitInfo$nonrefs;
typedef struct _jc_java_beans_ExplicitInfo$object	_jc_java_beans_ExplicitInfo$object;

typedef struct _jc_java_beans_ExplicitInfo$fields_struct	_jc_java_beans_ExplicitInfo$fields_struct;
typedef const struct _jc_java_beans_ExplicitInfo$vmethods	_jc_java_beans_ExplicitInfo$vmethods;
typedef const struct _jc_java_beans_ExplicitInfo$vtable	_jc_java_beans_ExplicitInfo$vtable;
typedef const struct _jc_java_beans_ExplicitInfo$vtype	_jc_java_beans_ExplicitInfo$vtype;

// Class fields structure
struct _jc_java_beans_ExplicitInfo$fields_struct {
	struct _jc_java_util_Vector$object	*emptyBeanInfos;
	struct _jc_java_util_Hashtable$object	*explicitBeanInfos;
};
extern _jc_java_beans_ExplicitInfo$fields_struct _jc_java_beans_ExplicitInfo$class_fields;

// Constructors
extern void _jc_java_beans_ExplicitInfo$method$_init$1022fe2092fb5155(_jc_env *, struct _jc_java_beans_ExplicitInfo$object *, struct _jc_java_lang_Class$object *, struct _jc_java_lang_Class$object *);

// Virtual methods
extern void _jc_java_beans_ExplicitInfo$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_beans_ExplicitInfo$object *);

// Virtual method descriptors
extern _jc_method _jc_java_beans_ExplicitInfo$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern void _jc_java_beans_ExplicitInfo$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_object *_jc_java_beans_ExplicitInfo$method$findExplicitBeanInfo$d047489a1ce54c58(_jc_env *, struct _jc_java_lang_Class$object *);
extern struct _jc_object *_jc_java_beans_ExplicitInfo$method$getBeanInfo$1a2d4f76ff6f4b42(_jc_env *, struct _jc_java_lang_ClassLoader$object *, struct _jc_java_lang_String$object *);
extern struct _jc_object *_jc_java_beans_ExplicitInfo$method$reallyFindExplicitBeanInfo$fbcf3580f3dda942(_jc_env *, struct _jc_java_lang_Class$object *);

// Virtual methods structure
struct _jc_java_beans_ExplicitInfo$vmethods {
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_beans_ExplicitInfo$object *);
};

// Vtable
struct _jc_java_beans_ExplicitInfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_beans_ExplicitInfo$vmethods	java_beans_ExplicitInfo;
};

// Vtype
struct _jc_java_beans_ExplicitInfo$vtype {
	_jc_type			type;
	_jc_java_beans_ExplicitInfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_ExplicitInfo$sub_refs {
	struct _jc_java_beans_BeanDescriptor$object	*explicitBeanDescriptor;
	_jc_object_array	*explicitBeanInfo;
	_jc_object_array	*explicitPropertyDescriptors;
	_jc_object_array	*explicitEventSetDescriptors;
	_jc_object_array	*explicitMethodDescriptors;
	_jc_object_array	*im;
	struct _jc_java_lang_Class$object	*propertyStopClass;
	struct _jc_java_lang_Class$object	*eventStopClass;
	struct _jc_java_lang_Class$object	*methodStopClass;
};

// Reference instance fields (object)
struct _jc_java_beans_ExplicitInfo$refs {
    _jc_java_beans_ExplicitInfo$sub_refs	java_beans_ExplicitInfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_ExplicitInfo$sub_nonrefs {
	jint	defaultProperty;
	jint	defaultEvent;
};

// Non-reference instance fields (object)
struct _jc_java_beans_ExplicitInfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_beans_ExplicitInfo$sub_nonrefs	java_beans_ExplicitInfo;
};

// Object instance structure
struct _jc_java_beans_ExplicitInfo$object {
	_jc_java_beans_ExplicitInfo$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_ExplicitInfo$vtype	*vtype;
	_jc_java_beans_ExplicitInfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_ExplicitInfo$vtype _jc_java_beans_ExplicitInfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_ExplicitInfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_ExplicitInfo$class_object;

#endif	/* _JC_java_beans_ExplicitInfo_H_ */

==> jc-1.4.6.tar.gz: java/beans/ExplicitInfo.h <==
// class java.beans.ExplicitInfo

// class file dependencies
// @dep_class 2882e26b5c43298f java_beans_ExplicitInfo
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_beans_ExplicitInfo_H_
#define _JC_java_beans_ExplicitInfo_H_

// Forward structure declarations
struct _jc_java_beans_BeanDescriptor$object;
struct _jc_java_beans_BeanInfo$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;
struct _jc_java_util_Vector$object;

// Typedefs
typedef struct _jc_java_beans_ExplicitInfo$sub_refs	_jc_java_beans_ExplicitInfo$sub_refs;
typedef struct _jc_java_beans_ExplicitInfo$sub_nonrefs	_jc_java_beans_ExplicitInfo$sub_nonrefs;
typedef struct _jc_java_beans_ExplicitInfo$refs	_jc_java_beans_ExplicitInfo$refs;
typedef struct _jc_java_beans_ExplicitInfo$nonrefs	_jc_java_beans_ExplicitInfo$nonrefs;
typedef struct _jc_java_beans_ExplicitInfo$object	_jc_java_beans_ExplicitInfo$object;

typedef struct _jc_java_beans_ExplicitInfo$fields_struct	_jc_java_beans_ExplicitInfo$fields_struct;
typedef const struct _jc_java_beans_ExplicitInfo$vmethods	_jc_java_beans_ExplicitInfo$vmethods;
typedef const struct _jc_java_beans_ExplicitInfo$vtable	_jc_java_beans_ExplicitInfo$vtable;
typedef const struct _jc_java_beans_ExplicitInfo$vtype	_jc_java_beans_ExplicitInfo$vtype;

// Class fields structure
struct _jc_java_beans_ExplicitInfo$fields_struct {
	struct _jc_java_util_Vector$object	*emptyBeanInfos;
	struct _jc_java_util_Hashtable$object	*explicitBeanInfos;
};
extern _jc_java_beans_ExplicitInfo$fields_struct _jc_java_beans_ExplicitInfo$class_fields;

// Constructors
extern void _jc_java_beans_ExplicitInfo$method$_init$1022fe2092fb5155(_jc_env *, struct _jc_java_beans_ExplicitInfo$object *, struct _jc_java_lang_Class$object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_beans_ExplicitInfo$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_beans_ExplicitInfo$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_beans_ExplicitInfo$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern void _jc_java_beans_ExplicitInfo$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_beans_ExplicitInfo$method$findExplicitBeanInfo$d047489a1ce54c58(_jc_env *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
extern void _jc_java_beans_ExplicitInfo$method$flushCaches$dd64232aebfb47ee(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_beans_ExplicitInfo$method$getBeanInfo$1a2d4f76ff6f4b42(_jc_env *, struct _jc_java_lang_ClassLoader$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_beans_ExplicitInfo$method$reallyFindExplicitBeanInfo$fbcf3580f3dda942(_jc_env *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_beans_ExplicitInfo$vmethods {
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_beans_ExplicitInfo$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_beans_ExplicitInfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_beans_ExplicitInfo$vmethods	java_beans_ExplicitInfo;
};

// Vtype
struct _jc_java_beans_ExplicitInfo$vtype {
	_jc_type			type;
	_jc_java_beans_ExplicitInfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_ExplicitInfo$sub_refs {
	struct _jc_java_beans_BeanDescriptor$object	*explicitBeanDescriptor;
	_jc_object_array	*explicitBeanInfo;
	_jc_object_array	*explicitPropertyDescriptors;
	_jc_object_array	*explicitEventSetDescriptors;
	_jc_object_array	*explicitMethodDescriptors;
	_jc_object_array	*im;
	struct _jc_java_lang_Class$object	*propertyStopClass;
	struct _jc_java_lang_Class$object	*eventStopClass;
	struct _jc_java_lang_Class$object	*methodStopClass;
};

// Reference instance fields (object)
struct _jc_java_beans_ExplicitInfo$refs {
    _jc_java_beans_ExplicitInfo$sub_refs	java_beans_ExplicitInfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_ExplicitInfo$sub_nonrefs {
	jint	defaultProperty;
	jint	defaultEvent;
};

// Non-reference instance fields (object)
struct _jc_java_beans_ExplicitInfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_beans_ExplicitInfo$sub_nonrefs	java_beans_ExplicitInfo;
};

// Object instance structure
struct _jc_java_beans_ExplicitInfo$object {
	_jc_java_beans_ExplicitInfo$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_ExplicitInfo$vtype	*vtype;
	_jc_java_beans_ExplicitInfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_ExplicitInfo$vtype _jc_java_beans_ExplicitInfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_ExplicitInfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_ExplicitInfo$class_object;

#endif	/* _JC_java_beans_ExplicitInfo_H_ */
